import { Skeleton } from "@/components/ui/skeleton";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useLocale } from "next-intl";
import { PageBreadcrumbSkeleton } from "./loading-skeleton/page-breadcrumb-skeleton";

export function HomeLoadingSkeleton() {
	const locale = useLocale() as Locale;
	const isRTL = locale === "ar";

	return (
		<>
			<div
				className={
					"grid grid-cols-4 grid-rows-[60vh_auto_40vh] lg:grid-cols-12 lg:grid-rows-[75vh_25vh]"
				}
				style={{ direction: "ltr" }}
			>
				<SkeletonSidebar />
				<SkeletonMainHero isRTL={isRTL} />
				<SkeletonBottomSection isRTL={isRTL} />
			</div>
			<FeaturesSkeleton isRTL={isRTL} />
			<CategoryListSkeleton isRTL={isRTL} />
			<CategorySwiperSkeleton />
			<ArrivalProductsSkeleton isRTL={isRTL} />
			<BestSellingSkeleton />
			<AboutSkeleton isRTL={isRTL} />
			<AdsSkeleton isRTL={isRTL} />
			<VideoProfileSkeleton isRTL={isRTL} />
			<TestimonialSkeleton isRTL={isRTL} />
			<StatisticsSkeleton isRTL={isRTL} />
			<BlogSkeleton />
		</>
	);
}

export function AboutLoadingSkeleton({ locale }: { locale: Locale }) {
	const isRTL = locale === "ar";

	return (
		<>
			<PageBreadcrumbSkeleton isRTL={isRTL} />
			<AboutSkeleton isRTL={isRTL} />
			<StatisticsSkeleton isRTL={isRTL} />
			<FeaturesSkeleton isRTL={isRTL} />
			<VideoProfileSkeleton isRTL={isRTL} />
			<ServicesListSkeleton isRTL={isRTL} />
			<FAQsSkeleton isRTL={isRTL} />
		</>
	);
}

export function ShopLoadingSkeleton({ locale }: { locale: Locale }) {
	const isRTL = locale === "ar";

	return (
		<>
			<PageBreadcrumbSkeleton isRTL={isRTL} />
			<MostSellingSkeleton isRTL={isRTL} />
			<CategorySwiperSkeleton />
			<ProductWithSalesSkeleton isRTL={isRTL} />
			<BestSellingSkeleton />
			<NewProductsLoadingSkeleton isRTL={isRTL} />
			<AdsSkeleton isRTL={isRTL} />
		</>
	);
}

function SkeletonSidebar() {
	return (
		<div
			className={cn(
				"col-span-4 row-span-3 bg-[#00629F] lg:col-span-3 lg:row-span-2",
			)}
		>
			<div className="flex h-full flex-col items-center p-4 md:p-6 md:px-10">
				<Skeleton className="mb-4 h-6 w-32" />
				<Skeleton className="mb-4 h-[120px] w-[120px] rounded-full" />
				<Skeleton className="mb-2 h-6 w-3/4" />
				<Skeleton className="mb-4 h-24 w-full" />
				<Skeleton className="mb-2 h-12 w-32" />
				<Skeleton className="h-12 w-12 self-end" />
			</div>
		</div>
	);
}

function SkeletonMainHero({ isRTL }: { isRTL: boolean }) {
	return (
		<div
			className={`relative col-span-4 row-start-1 lg:col-span-9 ${isRTL ? "lg:col-start-1" : "lg:col-start-4"}`}
		>
			<Skeleton className="absolute inset-0" />
			<div
				className={`absolute inset-0 flex flex-col justify-center p-4 md:p-8 ${isRTL ? "items-end" : "items-start"}`}
			>
				<Skeleton className="mb-4 h-12 w-3/4" />
				<Skeleton className="mb-4 h-24 w-full" />
				<Skeleton className="h-12 w-32" />
			</div>
		</div>
	);
}

function SkeletonBottomSection({ isRTL }: { isRTL: boolean }) {
	return (
		<div
			className={`col-span-4 row-start-3 bg-gray-50 lg:col-span-9 lg:row-start-2 ${isRTL ? "lg:col-start-1" : "lg:col-start-4"}`}
		>
			<div
				className={`flex h-full flex-col items-center justify-center gap-2 py-4 md:flex-row md:gap-2 md:py-6 ${isRTL ? "md:flex-row-reverse" : "md:flex-row"}`}
			>
				<Skeleton className="h-24 w-full" />
				<Skeleton className="h-24 w-32" />
			</div>
		</div>
	);
}

export function FeaturesSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="container mx-auto px-4 py-16 md:px-6 lg:px-8">
			<div className="grid grid-cols-1 gap-8 md:grid-cols-2 lg:grid-cols-3">
				{[1, 2, 3].map((index) => (
					<div
						key={index}
						className={`rounded-lg bg-white p-8 ${isRTL ? "text-right" : "text-left"
							}`}
						style={{
							boxShadow: "0 72px 24px -55px rgba(4, 37, 51, 0.08)",
						}}
					>
						<div className="mb-6 flex justify-center">
							<Skeleton className="h-12 w-12" />
						</div>
						<Skeleton className="mx-auto mb-4 h-6 w-2/3" />
						<Skeleton className="h-24 w-full" />
					</div>
				))}
			</div>
		</section>
	);
}

export function CategoryListSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="container mx-auto px-4 py-16 md:px-6 lg:px-8">
			<div className="grid grid-cols-1 gap-4 sm:grid-cols-2 lg:grid-cols-4">
				{[...Array(8)].map((_, index) => (
					<div
						key={index}
						className="flex h-[60px] items-center justify-between rounded-full bg-white px-4 py-2 md:h-[78px] md:px-6 md:py-4"
					>
						<div
							className={`flex flex-col ${isRTL ? "items-end" : "items-start"}`}
						>
							<Skeleton className="mb-1 h-4 w-16" />
							<Skeleton className="h-5 w-24" />
						</div>
						<Skeleton className="h-[40px] w-[40px] rounded-full md:h-[54px] md:w-[54px]" />
					</div>
				))}
			</div>
		</section>
	);
}

export function CategorySwiperSkeleton() {
	return (
		<div className="w-full px-4 py-8 md:px-6">
			<div className="grid grid-cols-1 gap-4 sm:grid-cols-2 lg:grid-cols-4">
				{[1, 2, 3, 4].map((index) => (
					<div
						key={index}
						className="flex h-[60px] items-center justify-between rounded-full bg-white px-4 py-2 md:h-[78px] md:px-6 md:py-4"
					>
						<div className="flex flex-col items-end">
							<Skeleton className="mb-1 h-4 w-16" />
							<Skeleton className="h-5 w-24" />
						</div>
						<Skeleton className="h-[40px] w-[40px] rounded-full md:h-[54px] md:w-[54px]" />
					</div>
				))}
			</div>
			<div className="mt-8 flex items-center justify-center gap-4">
				<Skeleton className="h-8 w-8 rounded-full" />
				<div className="flex gap-2">
					{[1, 2, 3].map((index) => (
						<Skeleton key={index} className="h-2 w-2 rounded-full" />
					))}
				</div>
				<Skeleton className="h-8 w-8 rounded-full" />
			</div>
		</div>
	);
}

export function ArrivalProductsSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="relative min-h-screen overflow-hidden">
			<div
				className={cn(
					"relative z-10 mx-auto grid min-h-screen w-full max-w-7xl gap-8 p-4 md:p-8 lg:p-16",
					"grid-cols-1 items-center lg:grid-cols-5",
					isRTL && "lg:grid-flow-col-dense"
				)}
			>
				{/* Products Grid Skeleton */}
				<div
					className={cn(
						"grid gap-4 md:gap-6",
						"grid-cols-1 sm:grid-cols-2",
						"lg:col-span-3",
						isRTL ? "lg:col-start-3" : "lg:col-start-1"
					)}
				>
					{[1, 2].map((index) => (
						<div key={index} className="relative overflow-hidden rounded-lg">
							<Skeleton className="aspect-square w-full" />
							<div className="absolute bottom-0 left-0 right-0 w-10/12 p-4">
								<Skeleton className="mb-2 h-6 w-3/4" />
								<div className="flex items-center gap-2">
									<Skeleton className="h-4 w-16" />
									<Skeleton className="h-5 w-20" />
								</div>
							</div>
						</div>
					))}
				</div>

				{/* Content Skeleton */}
				<div
					className={cn(
						"flex flex-col gap-6",
						"lg:col-span-2",
						isRTL ? "text-right lg:col-start-1" : "text-left lg:col-start-4"
					)}
				>
					<div className="space-y-2">
						<Skeleton className="h-4 w-24" />
						<div className={cn("flex gap-1", isRTL && "flex-row-reverse")}>
							<Skeleton className="h-1 w-6" />
							<Skeleton className="h-1 w-12" />
							<Skeleton className="h-1 w-24" />
						</div>
					</div>
					<Skeleton className="h-10 w-full" />
					<Skeleton className="h-20 w-full" />
					<Skeleton className="h-12 w-32" />
				</div>
			</div>
		</section>
	);
}

export function BestSellingSkeleton() {
	return (
		<section className="relative overflow-hidden py-4">
			<div className="absolute inset-0" />
			<div className="container relative mx-auto lg:px-40">
				<div className="rounded-lg p-8 shadow-lg backdrop-blur-sm">
					<div className="flex items-center justify-between px-2 lg:px-8">
						<div className="space-y-6 text-center">
							<Skeleton className="mx-auto h-6 w-40" />
							<Skeleton className="mx-auto h-8 w-64" />
							<Skeleton className="mx-auto h-20 w-full max-w-3xl" />
						</div>
					</div>
					<div className="mt-8 flex gap-4">
						{[1, 2, 3].map((index) => (
							<div key={index} className="w-full">
								<Skeleton className="aspect-[4/5] w-full rounded-lg" />
							</div>
						))}
					</div>
				</div>
			</div>
		</section>
	);
}

export function AboutSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="overflow-hidden bg-custom-background-third">
			<div className="container relative mx-auto px-4 py-24 lg:px-40">
				<div className="grid grid-cols-1 items-start gap-8 lg:grid-cols-12">
					{/* Content Skeleton */}
					<div
						className={cn(
							"flex h-[412px] max-w-[674px] flex-col justify-around rounded-lg bg-custom-background-light px-6 py-6",
							"lg:col-span-7",
							isRTL && "lg:col-start-6"
						)}
					>
						<div className="space-y-2">
							<Skeleton className="h-4 w-24" />
							<div className="flex gap-1">
								<Skeleton className="h-1 w-6" />
								<Skeleton className="h-1 w-12" />
								<Skeleton className="h-1 w-24" />
							</div>
						</div>
						<Skeleton className="h-20 w-full" />
						<Skeleton className="h-16 w-3/4" />
						<Skeleton className="h-[56px] w-[125px]" />
					</div>

					{/* Main image Skeleton */}
					<div
						className={cn("relative lg:col-span-5", isRTL && "lg:col-start-1")}
					>
						<div className="absolute -left-4 -top-4 h-full w-full bg-custom-border" />
						<Skeleton className="relative z-10 h-[576.74px] w-[487px] rounded-sm" />
					</div>

					{/* Bottom images Skeleton */}
					<div className="z-50 grid grid-cols-3 gap-4 md:-mt-24 lg:col-span-9">
						{[1, 2, 3].map((index) => (
							<Skeleton
								key={index}
								className="h-[161.28px] w-full rounded-sm"
							/>
						))}
					</div>
				</div>
			</div>
		</section>
	);
}

export function AdsSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="overflow-hidden bg-custom-background-third pb-12">
			<div className="relative min-h-[600px]">
				{/* Background Image Skeleton */}
				<Skeleton className="absolute inset-0" />

				{/* Main Content Container */}
				<div className="relative flex h-full min-h-[600px] items-center">
					{/* Content Grid */}
					<div className="relative grid w-full grid-cols-12">
						{/* Discount Badge Skeleton */}
						<div
							className={cn(
								"col-span-5 flex items-center justify-center p-8",
								isRTL ? "order-last" : "order-first"
							)}
						>
							<div className="relative h-44 w-44">
								<Skeleton className="h-full w-full rounded-full" />
							</div>
						</div>

						{/* Text Content Skeleton */}
						<div
							className={cn(
								"col-span-7 flex flex-col justify-center p-12",
								isRTL ? "items-end text-right" : "items-start text-left"
							)}
						>
							<div className="relative z-10 w-full max-w-2xl space-y-4 bg-custom-dark-veryDark/60 p-8 pt-4">
								<div className="flex items-center gap-2">
									<Skeleton className="h-4 w-20" />
									<Skeleton className="h-1 w-8" />
								</div>
								<Skeleton className="h-10 w-3/4" />
								<Skeleton className="h-24 w-full" />
								<div
									className={cn(
										"flex gap-4",
										isRTL ? "flex-row" : "flex-row-reverse"
									)}
								>
									<Skeleton className="h-14 w-32" />
									<Skeleton className="h-14 w-32" />
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}

export function VideoProfileSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="px-4 py-16 md:px-8 lg:px-40">
			<div className="grid grid-cols-1 gap-8 lg:grid-cols-2">
				{/* Video Section Skeleton */}
				<div className="space-y-4">
					<Skeleton className="aspect-video w-full rounded-lg" />
					<div className="grid grid-cols-5 gap-4">
						{Array.from({ length: 5 }).map((_, i) => (
							<Skeleton key={i} className="aspect-video w-full rounded-lg" />
						))}
					</div>
				</div>

				{/* Content Section Skeleton */}
				<div
					className={cn(
						"flex flex-col py-12",
						isRTL ? "items-end" : "items-start"
					)}
				>
					<div className="mb-8 flex w-full flex-col gap-6">
						<div
							className={cn(
								"flex items-center gap-2",
								isRTL && "flex-row-reverse"
							)}
						>
							<Skeleton className="h-1 w-8" />
							<Skeleton className="h-6 w-24" />
						</div>

						<Skeleton className="h-12 w-3/4" />
						<Skeleton className="h-24 w-full" />

						<div className="grid grid-cols-2 gap-3 md:grid-cols-3">
							{Array.from({ length: 6 }).map((_, i) => (
								<Skeleton key={i} className="h-10 w-full rounded-full" />
							))}
						</div>
					</div>

					<div
						className={cn(
							"mt-auto flex w-full items-center justify-between gap-4"
						)}
					>
						<Skeleton className="h-10 w-32" />
						<div className="flex gap-2">
							{Array.from({ length: 2 }).map((_, i) => (
								<Skeleton key={i} className="h-3 w-3 rounded-full" />
							))}
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}

export function TestimonialSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="overflow-hidden">
			<div className="container relative mx-auto max-w-7xl px-4 py-8 sm:py-12 lg:px-8">
				<div className="grid grid-cols-1 gap-8 lg:grid-cols-12">
					{/* Content Skeleton */}
					<div
						className={cn(
							"flex flex-col justify-between rounded-lg bg-custom-background-light p-6 shadow-[0_78px_34px_-45px_rgba(0,0,0,0.15)]",
							"lg:col-span-6 lg:h-[403px]"
						)}
					>
						{/* Section Header Skeleton */}
						<div
							className={cn(
								"mb-6 flex flex-col",
								isRTL ? "items-end" : "items-start"
							)}
						>
							<div className="flex items-center gap-2 pb-4 sm:pb-6">
								<Skeleton className="h-4 w-24" />
								<Skeleton className="h-1 w-8" />
							</div>
							<Skeleton className="h-8 w-3/4 sm:h-10 lg:h-12" />
						</div>
						<Skeleton className="mb-6 h-24 w-full" />
						<Skeleton className="h-12 w-full sm:h-[56px] sm:w-[125px]" />
					</div>

					{/* Main image skeleton */}
					<div className="relative lg:col-span-6">
						<div className="relative mx-auto aspect-square w-full max-w-[403px]">
							<Skeleton className="h-full w-full rounded-sm" />
						</div>
						<div className="absolute bottom-4 left-1/2 z-20 flex -translate-x-1/2 transform space-x-2">
							{[0, 1, 2].map((index) => (
								<Skeleton
									key={index}
									className="h-2 w-2 rounded-full sm:h-3 sm:w-3"
								/>
							))}
						</div>
					</div>

					{/* Wave Background Skeleton */}
					<div className="pointer-events-none absolute inset-0 z-0 overflow-hidden">
						<div className="absolute bottom-0 right-0 h-1/3 w-2/3 lg:h-2/3 lg:w-full">
							<Skeleton className="h-full w-full" />
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}

export function StatisticsSkeleton({ }: { isRTL?: boolean }) {
	return (
		<section className="relative overflow-hidden bg-[#0575DA]">
			<div className="container relative z-10 mx-auto px-4 py-8 lg:px-40">
				<div className="grid grid-cols-2 gap-8 text-center md:grid-cols-4 md:gap-4">
					{[...Array(4)].map((_, index) => (
						<div
							key={index}
							className="flex flex-col items-center justify-center"
						>
							<Skeleton className="mb-2 h-8 w-16 bg-white/50 md:h-10 md:w-20" />
							<Skeleton className="h-6 w-24 bg-white/50 md:h-7 md:w-28" />
						</div>
					))}
				</div>
			</div>

			{/* Divider Lines */}
			<div className="pointer-events-none absolute left-1/2 top-1/2 h-full w-full -translate-x-1/2 -translate-y-1/2">
				<div className="container mx-auto h-full px-4 lg:px-40">
					<div className="hidden h-full grid-cols-4 md:grid">
						<div className="border-r border-white/20" />
						<div className="border-r border-white/20" />
						<div className="border-r border-white/20" />
					</div>
				</div>
			</div>
		</section>
	);
}

export function BlogSkeleton() {
	return (
		<section className="px-4 py-16 md:px-8 lg:px-40">
			{/* Header Skeleton */}
			<div className="mb-12 flex flex-col items-center justify-between gap-8 md:flex-row">
				<Skeleton className="h-10 w-10 rounded-full" />
				<div className="text-center">
					<div className="mb-2 flex items-center justify-center">
						<Skeleton className="h-4 w-24" />
						<Skeleton className="ml-2 h-1 w-8" />
					</div>
					<Skeleton className="mx-auto mb-4 h-10 w-64" />
					<Skeleton className="mx-auto h-4 w-full max-w-3xl" />
				</div>
				<Skeleton className="h-10 w-10 rounded-full" />
			</div>

			{/* Blog Posts Skeleton */}
			<div className="grid grid-cols-1 gap-8 md:grid-cols-2 lg:grid-cols-3">
				{[...Array(3)].map((_, index) => (
					<div key={index} className="flex flex-col">
						<Skeleton className="aspect-[16/9] w-full" />
						<div className="mt-4 flex justify-between">
							<Skeleton className="h-4 w-24" />
							<Skeleton className="h-4 w-24" />
						</div>
						<Skeleton className="mt-2 h-6 w-3/4" />
						<Skeleton className="mt-2 h-4 w-full" />
						<Skeleton className="mt-1 h-4 w-full" />
						<Skeleton className="mt-1 h-4 w-2/3" />
					</div>
				))}
			</div>
		</section>
	);
}

export function FAQsSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="container mx-auto max-w-7xl px-4 py-16 lg:px-8">
			<div className="flex flex-col gap-8 lg:flex-row">
				{/* Image Column Skeleton */}
				<div
					className={cn("w-full lg:w-1/2", isRTL ? "order-2" : "order-none")}
				>
					<Skeleton className="aspect-[4/3] w-full rounded-lg" />
				</div>

				{/* Content Column Skeleton */}
				<div className={cn("w-full lg:w-1/2", isRTL && "order-1")}>
					<div className="mb-8">
						<div className="mb-2 flex items-center gap-1">
							<Skeleton className="h-4 w-24" />
							<Skeleton className="h-1 w-4" />
							<Skeleton className="h-1 w-8" />
							<Skeleton className="h-1 w-12" />
						</div>
						<Skeleton className="h-8 w-3/4" />
					</div>

					<div className="space-y-4">
						{[1, 2, 3, 4].map((index) => (
							<div key={index} className="space-y-2">
								<Skeleton className="h-8 w-full" />
								<Skeleton className="h-4 w-3/4" />
							</div>
						))}
					</div>
				</div>
			</div>
		</section>
	);
}

export function ServicesListSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="container mx-auto max-w-7xl px-4 py-16 lg:px-8">
			<div className="grid gap-6 md:grid-cols-2 lg:grid-cols-3">
				{[1, 2, 3, 4, 5, 6].map((index) => (
					<div
						key={index}
						className="group relative overflow-hidden border-none"
					>
						{/* Image Skeleton */}
						<Skeleton className="h-[205px] w-full" />

						{/* Content Skeleton */}
						<div
							className={cn(
								"relative mt-auto min-h-[200px] bg-white/95 p-6",
								isRTL ? "text-right" : "text-left"
							)}
						>
							<div className="mb-4">
								<div
									className={cn(
										"inline-flex h-12 w-12 items-center justify-center rounded-lg",
										isRTL ? "float-right ml-4" : "float-left mr-4"
									)}
								>
									<Skeleton className="h-full w-full rounded-lg" />
								</div>
								<Skeleton className="h-6 w-3/4" />
							</div>
							<div className="space-y-2">
								<Skeleton className="h-4 w-full" />
								<Skeleton className="h-4 w-5/6" />
								<Skeleton className="h-4 w-4/6" />
							</div>
						</div>
					</div>
				))}
			</div>
		</section>
	);
}

export function MostSellingSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<div
			className={cn(
				"flex flex-col-reverse gap-6 lg:flex-row",
				isRTL ? "lg:flex-row-reverse" : ""
			)}
		>
			{/* Products Grid */}
			<div className="w-full lg:w-[55%]">
				<div className="grid grid-cols-1 gap-4 sm:grid-cols-2">
					{[...Array(4)].map((_, index) => (
						<div
							key={index}
							className="flex flex-row items-center gap-4 rounded-lg border p-4"
						>
							<Skeleton className="h-[118px] w-[118px] flex-shrink-0 rounded-lg" />
							<div className="flex flex-col items-center gap-2 text-center sm:items-start sm:text-start">
								<Skeleton className="h-6 w-32" />
								<Skeleton className="h-9 w-24" />
							</div>
						</div>
					))}
				</div>
			</div>

			{/* Featured Image */}
			<div className="w-full lg:w-[45%]">
				<div className="relative h-[350px] w-full overflow-hidden rounded-lg lg:h-full">
					<Skeleton className="absolute inset-0" />
					<div className="absolute bottom-0 left-0 right-0 p-6">
						<Skeleton className="mb-4 h-8 w-48" />
						<Skeleton className="h-10 w-32" />
					</div>
				</div>
			</div>
		</div>
	);
}

export function ProductWithSalesSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<div
			className={cn(
				"mx-auto flex items-center overflow-hidden rounded-lg px-4 py-3"
			)}
		>
			{/* Product Details */}
			<div className="flex flex-1 flex-col gap-2 p-4">
				{/* Product Name */}
				<Skeleton
					className={cn("h-8 w-3/4", isRTL ? "self-end" : "self-start")}
				/>

				{/* Pricing */}
				<div
					className={cn(
						"flex items-center justify-start gap-1",
						isRTL && "flex-row-reverse"
					)}
				>
					<Skeleton className={cn("h-4 w-16")} />
					<Skeleton className={cn("h-4 w-16")} />
				</div>

				{/* Stock Info */}
				<Skeleton
					className={cn("h-4 w-24", isRTL ? "self-end" : "self-start")}
				/>

				{/* Progress Bar */}
				<div className="mb-2">
					<Skeleton className={cn("h-5 w-full")} />
				</div>

				{/* Actions */}
				<div
					className={cn(
						"flex items-center justify-start",
						isRTL ? "flex-row-reverse" : "flex-row"
					)}
				>
					<Skeleton className="h-10 w-10 rounded-full bg-white" />
					<Skeleton className={cn("ml-2 h-12 flex-1 rounded-full")} />
				</div>
			</div>
			{/* Product Image */}
			<Skeleton className="aspect-square w-40 shrink-0 rounded-md" />
		</div>
	);
}
export function NewProductsLoadingSkeleton({ isRTL }: { isRTL: boolean }) {
	return (
		<section className="container mx-auto max-w-7xl px-4 py-16 lg:px-8">
			<div
				className={cn("mb-6 flex flex-col justify-between gap-6 md:flex-row")}
			>
				<div>
					<Skeleton className="h-6 w-40 bg-custom-primary-accent/20" />
					<Skeleton className="mt-4 h-10 w-full max-w-lg" />
				</div>
				<Skeleton className="h-14 w-full max-w-[178px] sm:w-auto sm:self-end" />
			</div>

			<div className="flex flex-col gap-4 lg:flex-row">
				{/* Content Grid */}
				<div className="flex flex-1 flex-col gap-4 lg:flex-row">
					{/* Featured Item */}
					<div className="flex w-full lg:w-1/2">
						<div className="group relative flex h-[482px] w-full overflow-hidden rounded-lg">
							<Skeleton className="h-full w-full" />

							{/* Navigation Buttons */}
							<div className="absolute inset-0 flex items-center justify-between px-4">
								<Skeleton className="h-12 w-12 rounded-full bg-white/50 text-custom-dark-veryDark backdrop-blur-sm" />
								<Skeleton className="h-12 w-12 rounded-full bg-white/50 text-custom-dark-veryDark backdrop-blur-sm"></Skeleton>
							</div>

							<div
								className={cn(
									"absolute bottom-0 flex w-full flex-col gap-4 p-6",
									isRTL ? "items-end text-right" : "items-start text-left"
								)}
							>
								<div className="absolute bottom-0 left-0 w-[100%] rounded-lg bg-custom-dark-veryDark/85 p-6">
									<Skeleton className="h-8 w-3/4" />
									<Skeleton className="mt-2 h-6 w-1/2" />
								</div>
							</div>
						</div>
					</div>

					{/* Carousel Items */}
					<div className="w-full lg:w-1/2">
						<div className="flex h-full flex-col gap-4">
							{[1, 2].map((item) => (
								<div
									key={item}
									className="relative flex h-[234px] w-full shrink-0 gap-2 overflow-hidden rounded-lg"
								>
									<Skeleton className="h-full w-full" />
									<div className="absolute bottom-0 left-0 w-[40%] rounded-lg bg-custom-dark-veryDark/85 p-4">
										<Skeleton className="h-6 w-3/4" />
										<Skeleton className="mt-2 h-5 w-1/2" />
									</div>
								</div>
							))}
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}
